@@ -5,6 +5,7 @@ import tempfile
 import mimetypes
 import copy
 import hashlib
+import urllib
 import email
 import csv
 import re
@@ -99,14 +100,14 @@ class EObject(object):
             interface: :class:`Interface`
                 Main interface reference.
         """
-        self._uri = translate_uri(uri)
-        self._urn = uri_last(self._uri)
+        self._uri = urllib.quote(translate_uri(uri))
+        self._urn = urllib.unquote(uri_last(self._uri))
         self._urt = uri_nextlast(self._uri)
         self._intf = interface
         self.attrs = EAttrs(self)
 
     def __repr__(self):
-        return '<%s Object> %s'%(self.__class__.__name__, uri_last(self._uri))
+        return '<%s Object> %s'%(self.__class__.__name__, urllib.unquote(uri_last(self._uri)))
 
     def _getcell(self, col):
         """ Gets a single property of the element resource.
@@ -352,7 +353,7 @@ class CObject(object):
     def _call(self, columns):
         try:
             query_string = '?format=json&columns=%s'%','.join(columns)
-            return self._intf._get_json(translate_uri(self._cbase) + query_string)
+            return self._intf._get_json(urllib.quote(translate_uri(self._cbase)) + query_string)
         except Exception, e:
             if DEBUG:
                 print e
@@ -369,7 +370,7 @@ class CObject(object):
 
             for res in self._call([id_header] + self._columns):
                 try:
-                    eid = res[id_header]
+                    eid = urllib.unquote(res[id_header])
                     if fnmatch(eid, self._pattern):
                         Klass = globals()[uri_last(self._cbase).rstrip('s').title()]
                         eobj = Klass(join_uri(self._cbase, eid), self._intf)
@@ -512,16 +513,16 @@ class CObject(object):
                 is given, a list of tuple is returned instead of a list.
         """
         if args == ():
-            return [uri_last(eobj._uri) for eobj in self]
+            return [urllib.unquote(uri_last(eobj._uri)) for eobj in self]
         else:
             ret = ()
             for arg in args:
                 if arg == 'id':
                     self._id_header = 'ID'
-                    ret += ([uri_last(eobj._uri) for eobj in self], )
+                    ret += ([urllib.unquote(uri_last(eobj._uri)) for eobj in self], )
                 elif arg == 'label':
                     self._id_header = 'label'
-                    ret +=  ([uri_last(eobj._uri) for eobj in self], )
+                    ret +=  ([urllib.unquote(uri_last(eobj._uri)) for eobj in self], )
                 else:
                     ret += ([eobj for eobj in self], )
 
